@@ -22,11 +22,12 @@ check_can_create_file <- function(
     } else {
       # Delete the file
       file.remove(filename)
-      if (file.exists(filename)) {
-        stop(
+      testthat::expect_true(
+        !file.exists(filename),
+        info = paste0(
           "Cannot delete the file already present at location ", filename
         )
-      }
+      )
     }
   }
   tryCatch(
@@ -41,9 +42,10 @@ check_can_create_file <- function(
     )
   }
   file.remove(filename)
-  if (file.exists(filename)) {
-    stop(
+  testthat::expect_true(
+    !file.exists(filename),
+    info = paste0(
       "Cannot delete the temporary file created at location ", filename
     )
-  }
+  )
 }
